@@ -1,7 +1,8 @@
-__VERSION__ = '1.6'
+__VERSION__ = '1.7'
 
 from pymls.solver import Solver
 from pymls.layers import Layer, StochasticLayer
-from pymls.media import from_yaml
+
+from mediapack.utils import from_yaml
 
 import pymls.backing as backing
