@@ -29,7 +29,7 @@ from pymls.analysis import Analysis
 from pymls.interface.utils import generic_interface, rigid_interface
 from pymls.layers import generic_layer, StochasticLayer
 import pymls.backing as backing
-from pymls.media import Air
+from mediapack import Air
 
 
 class IncompleteDefinitionError(Exception):
@@ -121,7 +121,7 @@ class Solver(object):
 
         return True
 
-    def solve(self, frequencies=None, angles=0, n_draws=1000, prng_state=None, full_solution=False):
+    def solve(self, frequencies=None, angles=0, n_draws=1000, prng_state=None):
         """
         Starts the solving process w/w stochastic parameters.
 
@@ -141,8 +141,6 @@ class Solver(object):
             Number of draws for the stochastic analyses.
         prng_state : tuple
             Saved state for Numpy's pseudo random number generator (see `numpy.random.get_state`)
-        full_solution : bool
-            If true, returns the full solution vector in the resultset
 
         .. _numpy.random.get_state: https://docs.scipy.org/doc/numpy/reference/generated/numpy.random.get_state.html
 
@@ -169,8 +167,7 @@ class Solver(object):
                 'auto',
                 frequencies,
                 angles,
-                len(self.stochastic_layers) > 0,
-                full_solution
+                len(self.stochastic_layers) > 0
             )]
 
         self.n_analyses = 0
@@ -303,16 +300,12 @@ class Solver(object):
             'R': [],
             'T': [],
         }
-        if a.full_solution:
-            result['full_solution'] = []
 
         for f, angle in a:
-            (R, T, *extra) = self.__solve_one_frequency(f, angle, a.full_solution)
+            (R, T) = self.__solve_one_frequency(f, angle)
             result['R'].append(R)
             if T is not None:
                 result['T'].append(T)
-            if extra != []:
-                result['full_solution'].append(extra[0])
 
         return result
 
@@ -322,7 +315,7 @@ class Solver(object):
         for _,l in self.stochastic_layers:
             l.reinit()
 
-    def __solve_one_frequency(self, frequency, theta_inc, full_solution):
+    def __solve_one_frequency(self, frequency, theta_inc):
         """ Solve for one frequency `frequency` and one angle `theta_inc`
 
         Parameters
@@ -331,8 +324,6 @@ class Solver(object):
             Frequency for the resolution
         theta_inc :
             Angle of incidence for the resolution
-        full_solution: bool
-            If True, return the full solution vector
 
         Returns
         -------
@@ -340,8 +331,6 @@ class Solver(object):
             Reflection coefficient
         trans_coefficient : complex or None
             Transmission coefficient
-        extra:
-            Extra outputs (full solution vector for instance)
         """
 
         omega = frequency*2*np.pi
@@ -426,8 +415,7 @@ class Solver(object):
         else:
             trans_coefficient = None
 
-        extra = [X] if full_solution else []
-        return (reflx_coefficient, trans_coefficient, *extra)
+        return (reflx_coefficient, trans_coefficient)
 
     def compute_fields(self, layer_id, frequency, theta_inc):
         """ Returns the backpropagation matrix from the first interface to layer num.
